@@ -3,7 +3,7 @@
 """
 Created on Fri Jun 14 09:17:50 2019
 
-@author: admin2
+@author: Rajiv Sambasivan
 """
 import os
 
@@ -34,12 +34,13 @@ class ArangoPipeConfig:
     
     def set_dbconnection(self, hostname = "localhost", port = 8529,\
                          root_user = 'root', \
-                         root_user_password = 'open sesame'):
+                         root_user_password = 'open sesame',\
+                         arangopipe_dbname = "arangopipe"):
         self.cfg['arangodb']['root_user'] = root_user
         self.cfg['arangodb']['root_user_password'] = root_user_password
         self.cfg['arangodb']['host'] = hostname
         self.cfg['arangodb']['port'] = port
-        
+        self.cfg['arangodb']['arangopipe_dbname'] = arangopipe_dbname
         return
       
         
